@@ -6,6 +6,7 @@ test.df3 <- data.frame(Mobility=c(1,2,3,4,5),Care=c(1,5,4,3,2),Activities=c(1,5,
 test.df4 <- data.frame(MO=c(1,2,2),SC=c(2,4,3),UA=c(3,1,4),PD=c(4,1,2),AD=c(5,2,1),age=c(30,50,5),sex=c("f","f","m"))
 test.df5 <- data.frame(Utility=c(0.922,0.590,-0.226,0.435), Age=c(18,36,71,30), Sex=c("m","f","f","f"), bandwidth=c(0,0,0,0.1))
 test.df6 <- data.frame(Utility=c(-0.226,0.922), Age=c(18,30), Sex=c("male","female"), bwidth=c(0,""))
+test.df7 <- data.frame(Age = c(50,30,70), Sex = c("m","f","m"), Utility = c(0.715,0.435,0.95))
 test.char <- c(12321, 23132, 32123)
 test.char2 <- c(11211, "12321", NA, "abcd", "")
 
@@ -46,6 +47,10 @@ test_that("Wrapper function gives correct answer", {
   expect_equal(eq5d(test.df4,version="5L", type="DSU", country="UK", age="age", sex="sex"), c(0.067,0.761,0.609))
   expect_equal(eq5d(test.df5,version="5L", type="DSU", country="UK", bwidth="bandwidth", utility="Utility"), c(0.893,0.353,-0.409,0.297))
   expect_equal(eq5d(test.df6,version="5L", type="DSU", country="UK", ignore.invalid = TRUE), c(-0.427,NA))
+  expect_equal(eq5d(test.df7,version="5L", type="DSU", country="UK", bwidth=0.1), c(0.637,0.297,0.844))
+  expect_equal(eq5d(test.df7,version="5L", type="DSU", country="UK", bwidth=0.0001), c(0.670,0.302,0.935))
+  expect_equal(eq5d(0.715, country="UK", type="DSU", version="5L", age=50, sex="m", bwidth=0.1), 0.637)
+  expect_equal(eq5d(0.715, country="UK", type="DSU", version="5L", age=50, sex="m", bwidth=0.0001), 0.670)
   expect_error(eq5d(test.df, version="3L", type="TTO", country="USA", dimensions=c("Mob", "Self", "Active", "Pain", "Anx")))
 })
 
@@ -57,6 +62,7 @@ test_that("eq5d throws error for incorrect parameters", {
   expect_error(eq5d(10000, version="5L", type="VT", country="England"))
   expect_error(eq5d(99999, version="5L", type="VT", country="England"))
   expect_error(eq5d(0.375, country="UK", version="5L", type="DSU", age=50, sex="male", bwidth=-0.00001))
+  expect_error(eq5d(test.df7,version="5L", type="DSU", country="UK", bwidth=c(0.0001, 0.1)))
 })
 
 test_that("when ignore.invalid flag is TRUE the correct answer is returned", {
